==> haskell-mockery-0.3.5-697-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mockery
version:              0.3.5
visibility:           public
id:                   mockery-0.3.5-9SsWPDtxfyK2Sv3AW4ser3
key:                  mockery-0.3.5-9SsWPDtxfyK2Sv3AW4ser3
license:              MIT
copyright:            (c) 2015-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Support functions for automated testing
description:          Support functions for automated testing
category:             Testing
abi:                  6a5a946991c331ffe775898f45c4d7da
exposed:              True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging

hidden-modules:       Paths_mockery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mockery
hs-libraries:         HSmockery-0.3.5-9SsWPDtxfyK2Sv3AW4ser3
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 directory-1.3.7.1 filepath-1.4.2.2
    logging-facade-0.3.1-HVIPKzcZEa33CYRIxlzYKL
    temporary-1.3-DiUtnHq59dHLFRsQDPnjYs

haddock-interfaces:   /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html:         /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mockery-0.3.5-698-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mockery.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mockery
version:              0.3.5
visibility:           public
id:                   mockery-0.3.5-4j6kpwFiQI31dr6rrwrq0z
key:                  mockery-0.3.5-4j6kpwFiQI31dr6rrwrq0z
license:              MIT
copyright:            (c) 2015-2016 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             Support functions for automated testing
description:          Support functions for automated testing
category:             Testing
abi:                  52f99f0d5c9eceec583cfdf40f3bab58
exposed:              True
exposed-modules:
    Test.Mockery.Directory Test.Mockery.Environment
    Test.Mockery.Logging

hidden-modules:       Paths_mockery
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mockery-0.3.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mockery
hs-libraries:         HSmockery-0.3.5-4j6kpwFiQI31dr6rrwrq0z
depends:
    base-4.17.2.1 base-compat-0.12.3-H9qTMlLoDHsHlMi1O3x7Rp
    bytestring-0.11.5.3 directory-1.3.7.1 filepath-1.4.2.2
    logging-facade-0.3.1-LFCo9Qe59ed8huYTy1WtIG
    temporary-1.3-7zyjAjJQKm1EuSr6RhrC3V

haddock-interfaces:   /usr/share/doc/haskell-mockery/html/mockery.haddock
haddock-html:         /usr/share/doc/haskell-mockery/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
